@@ -7,6 +7,7 @@ use solana_sdk::{
     system_program, system_transaction,
     transaction::Transaction,
 };
+use solana_vote_program::vote_transaction;
 
 pub fn test_tx() -> Transaction {
     let keypair1 = Keypair::new();
@@ -40,3 +41,16 @@ pub fn test_multisig_tx() -> Transaction {
         instructions,
     )
 }
+
+pub fn vote_tx() -> Transaction {
+    let keypair = Keypair::new();
+    vote_transaction::new_vote_transaction(
+        vec![2],
+        Hash::default(),
+        Hash::default(),
+        &keypair,
+        &keypair,
+        &keypair,
+        None,
+    )
+}
